@@ -1,3 +1,5 @@
+use 5.008;
+
 package Business::ISBN10;
 use strict;
 use base qw(Business::ISBN);
@@ -5,8 +7,6 @@ use base qw(Business::ISBN);
 use Business::ISBN qw(:all);
 
 use vars qw(
-	$VERSION
-	$debug
 	$MAX_GROUP_CODE_LENGTH
 	%ERROR_TEXT
 	);
@@ -15,7 +15,7 @@ use Carp qw(carp croak cluck);
 
 my $debug = 0;
 
-$VERSION   = '3.004';
+our $VERSION   = '3.007';
 
 sub _max_length { 10 }
 
@@ -106,7 +106,7 @@ brian d foy C<< <bdfoy@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright © 2001-2017, brian d foy <bdfoy@cpan.org>. All rights reserved.
+Copyright © 2001-2022, brian d foy <bdfoy@cpan.org>. All rights reserved.
 
 This module is licensed under the Artistic License 2.0. See the LICENSE
 file in the distribution, or https://opensource.org/licenses/Artistic-2.0
